# Xircuits Component Library List


## Internal Library

These components will always be included in the Xircuits installation.

<div align="center">

| Name     | Description                                                                                    |                                                                                                                                                            |
| -------- | ---------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| Tensorflow Keras | Deep learning related components using Tensorflow Keras.                                       | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_tensorflow_keras) |
| Pytorch  | Components that use Pytorch's ML library.                                                      | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_pytorch)   |
| SKlearn | Scikit learn components. | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_sklearn) |
| XGBoost |  Optimized distributed gradient boosting library. | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_xgboost) |
| Spark    | Components built using the Pyspark library. Run these components with the Xircuits Remote Run! | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_spark)       |
| Template | Great components for new learners and to experiment outputs.                                   | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_template) |
| Utils    | Commonly used components for day-to-day workflows.                                             | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_utils)       |
| Controlflow | Components to enable ifs and loops. | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_controlflow) |

</div>


## External Library

Recognized additional component libraries that you can download and install using:

```
$ xircuits install <component library name>
```

<div align="center">


### 🤖 AI Agents
| Name | Description | Version |
| ---- | ----------- | ------- |
| [GPT Agent Toolkit](https://github.com/XpressAI/xai-gpt-agent-toolkit) | Experiment with and create Collaborative Large Language Model-based automatons (Agents) in the style of BabyAGI and Auto-GPT. | 0.1.0 |
| [Vecto](https://github.com/XpressAI/xai-vecto) | The power of vector embeddings in Xircuits. | 0.1.0 |
| [OpenAI](https://github.com/XpressAI/xai-openai) | Easily integrate OpenAI's functionalities, such as retrieving models and generating text, into your Xircuits projects! | 0.1.0 |
| [Anthropic](https://github.com/XpressAI/xai-anthropic) | Advanced components for anthropic principles. | - |
| [HF Agent](https://github.com/XpressAI/xai-hfagent) | Advanced components for hugging face agents. | - |
| [Actors](https://github.com/XpressAI/xai-actors) | Components for creating actor models. | - |
| [VertexAI](https://github.com/XpressAI/xai-google-vertexai) | Components that interfaces with Google Vertex AI! | - |

### 📊 Data Science and Machine Learning
| Name | Description | Version |
| ---- | ----------- | ------- |
| [Pycaret](https://github.com/XpressAI/xai-pycaret) | A component library built using Pycaret's API! Complete with examples for NLP, anomaly detection, classification, clustering, as well as regression. | 0.1.0 |
| [RPA](https://github.com/yuenherny/xai-rpa) | Robotic process automation library to automate routine and repetitive tasks! | 0.2.1 |
| [Streamlit](https://github.com/XpressAI/xai-streamlit) | Turn Xircuits workflows into shareable web apps in minutes. | 0.1.0 |

### 💬 Communication
| Name | Description | Version |
| ---- | ----------- | ------- |
| [Slack](https://github.com/XpressAI/xai-slack) | Xircuits Component Library to interface with Slack! | 0.1.0 |
| [Discord](https://github.com/XpressAI/xai-discord) | Create Discord Bots in seconds. | 0.1.0 |

### 📭 Message Queues
| Name | Description | Version |
| ---- | ----------- | ------- |
| [RabbitMQ](https://github.com/XpressAI/xai-rabbitmq) | Message broker in Xircuits that just works. | 0.1.0 |
| [MQTT](https://github.com/XpressAI/xai-mqtt) | Xircuits library that implements the standard for IoT Messaging. | 0.1.0 |

### 🗃 Databases & Servers
| Name | Description | Version |
| ---- | ----------- | ------- |
| [SQLite](https://github.com/XpressAI/xai-sqlite) | Components for interfacing with SQLite databases. | - |
| [Flask](https://github.com/XpressAI/xai-flask) | Components for developing Flask applications. | - |


### 🌍 Cloud Services
| Name | Description | Version |
| ---- | ----------- | ------- |
| [GDrive](https://github.com/XpressAI/xai-gdrive) | Components for interacting with Google Drive. | - |
| [GSpread](https://github.com/XpressAI/xai-gspread) | Components for interfacing with Google Sheets. | - |

</div>

Want your component library listed here? Just submit a PR to the Xircuits repository. For more information, refer to the [Xircuits component library documentation](https://xircuits.io/docs/component-library/).